#!/usr/bin/env python
import io

from setuptools import find_packages, setup


readme = io.open('README.rst', 'r', encoding='utf-8').read()


setup(
    name='aratrum',
    description='A simple json configuration handler.',
    long_description=readme,
    url='https://github.com/Vesuvium/aratrum',
    author='Jacopo Cascioli',
    author_email='jacopocascioli@gmail.com',
    license='MIT',
    version='0.3.2',
    packages=find_packages(),
    tests_require=[
        'pytest',
        'pytest-mock'
    ],
    setup_requires=['pytest-runner'],
    install_requires=[
        'ujson>=1.35'
    ],
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
    ]
)



# -*- coding: utf-8 -*-
import os

import ujson


class Aratrum:
    """
    Provides read/write access to the configuration.
    """
    default = {}

    def __init__(self, filename='config.json'):
        self.filename = os.path.join(os.getcwd(), filename)
        self.set_to_default()

    def get(self):
        """
        Loads the configuration and returns it as a dictionary
        """
        with open(self.filename, 'r') as f:
            self.config = ujson.load(f)
        return self.config

    def set_to_default(self):
        """
        Sets the configuration to default values
        """
        self.config = self.default

    def set(self, option, value):
        """
        Sets an option to a value.
        """
        if self.config is None:
            self.config = {}
        self.config[option] = value

    def delete(self, option):
        """
        Deletes an option if exists
        """
        if self.config is not None:
            if option in self.config:
                del self.config[option]

    def save(self):
        """
        Saves the configuration
        """
        with open(self.filename, 'w') as f:
            ujson.dump(self.config, f, indent=4)
